==> qtjambi-xml-debuginfo-linux-x64-5.15.23.jar: sources/QtJambiXml/QDomDocumentFragment_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomDocumentFragment(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomDocumentFragment")
    QDomDocumentFragment *_ptr = reinterpret_cast<QDomDocumentFragment *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomDocumentFragment()
void __qt_construct_QDomDocumentFragment(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentFragment()")
    Q_UNUSED(__java_arguments)
    QDomDocumentFragment *__qt_this = new(__qtjambi_ptr) QDomDocumentFragment();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomDocumentFragment::QDomDocumentFragment()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_initialize_1native__Lio_qt_xml_QDomDocumentFragment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentFragment::QDomDocumentFragment()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentFragment, sizeof(QDomDocumentFragment), typeid(QDomDocumentFragment), 0, false, &deleter_QDomDocumentFragment, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomDocumentFragment(QDomDocumentFragment)
void __qt_construct_QDomDocumentFragment_cref_QDomDocumentFragment(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentFragment(QDomDocumentFragment)")
    jobject x0 = __java_arguments[0].l;
    const QDomDocumentFragment& __qt_x0 = qtjambi_cast<const QDomDocumentFragment&>(__jni_env, x0);
    QDomDocumentFragment *__qt_this = new(__qtjambi_ptr) QDomDocumentFragment(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomDocumentFragment::QDomDocumentFragment(QDomDocumentFragment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_initialize_1native__Lio_qt_xml_QDomDocumentFragment_2Lio_qt_xml_QDomDocumentFragment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentFragment::QDomDocumentFragment(QDomDocumentFragment)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentFragment_cref_QDomDocumentFragment, sizeof(QDomDocumentFragment), typeid(QDomDocumentFragment), 0, false, &deleter_QDomDocumentFragment, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomDocumentFragment
void __qt_destruct_QDomDocumentFragment(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomDocumentFragment")
    reinterpret_cast<QDomDocumentFragment*>(ptr)->~QDomDocumentFragment();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomDocumentFragment::operator=(QDomDocumentFragment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_assign_1native_1cref_1QDomDocumentFragment__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomDocumentFragment *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentFragment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentFragment::operator=(QDomDocumentFragment)", __this_nativeId)
        const QDomDocumentFragment& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomDocumentFragment>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomDocumentFragment *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentFragment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomDocumentFragment(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomDocumentFragment>("QDomDocumentFragment", "io/qt/xml/QDomDocumentFragment");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomDocumentFragment, {
        ConstructorInfo(&__qt_construct_QDomDocumentFragment, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomDocumentFragment_cref_QDomDocumentFragment, "Lio/qt/xml/QDomDocumentFragment;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomDocumentFragment);
    registerMetaType<QDomDocumentFragment>("QDomDocumentFragment");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiXml/QDomDocumentFragment_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomDocumentFragment(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomDocumentFragment")
    QDomDocumentFragment *_ptr = reinterpret_cast<QDomDocumentFragment *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomDocumentFragment()
void __qt_construct_QDomDocumentFragment_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentFragment()")
    Q_UNUSED(__java_arguments)
    QDomDocumentFragment *__qt_this = new(__qtjambi_ptr) QDomDocumentFragment();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDomDocumentFragment(QDomDocumentFragment)
void __qt_construct_QDomDocumentFragment_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentFragment(QDomDocumentFragment)")
    jobject x0 = __java_arguments[0].l;
    const QDomDocumentFragment& __qt_x0 = qtjambi_cast<const QDomDocumentFragment& >(__jni_env, x0);
    QDomDocumentFragment *__qt_this = new(__qtjambi_ptr) QDomDocumentFragment(__qt_x0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDomDocumentFragment
void __qt_destruct_QDomDocumentFragment(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomDocumentFragment")
    reinterpret_cast<QDomDocumentFragment*>(ptr)->~QDomDocumentFragment();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomDocumentFragment::QDomDocumentFragment()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_initialize_1native__Lio_qt_xml_QDomDocumentFragment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentFragment::QDomDocumentFragment()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentFragment_0, sizeof(QDomDocumentFragment), typeid(QDomDocumentFragment), false, &deleter_QDomDocumentFragment, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomDocumentFragment::QDomDocumentFragment(QDomDocumentFragment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_initialize_1native__Lio_qt_xml_QDomDocumentFragment_2Lio_qt_xml_QDomDocumentFragment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentFragment::QDomDocumentFragment(QDomDocumentFragment)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentFragment_1, sizeof(QDomDocumentFragment), typeid(QDomDocumentFragment), false, &deleter_QDomDocumentFragment, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomDocumentFragment::operator=(QDomDocumentFragment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_assign_1native_1cref_1QDomDocumentFragment__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomDocumentFragment *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentFragment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentFragment::operator=(QDomDocumentFragment)", __qt_this)
        const QDomDocumentFragment& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomDocumentFragment>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentFragment_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomDocumentFragment *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentFragment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomDocumentFragment(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomDocumentFragment>("QDomDocumentFragment", "io/qt/xml/QDomDocumentFragment");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomDocumentFragment, {
        ConstructorInfo(&__qt_construct_QDomDocumentFragment_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomDocumentFragment_1, "Lio/qt/xml/QDomDocumentFragment;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomDocumentFragment);
    registerMetaType<QDomDocumentFragment>("QDomDocumentFragment");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
